@@ -2,8 +2,8 @@
 
 ;; Copyright (C) 2019-2024 Yves Zoundi
 
-;; Package-Version: 1.35
-;; Package-Revision: 492282d653c9
+;; Package-Version: 20250527.1232
+;; Package-Revision: b42b5190f3f5
 ;; Author: Yves Zoundi <yves_zoundi@hotmail.com> and contributors
 ;; Maintainer: Yves Zoundi <yves_zoundi@hotmail.com>
 ;; URL: https://github.com/yveszoundi/eglot-java
@@ -1438,7 +1438,7 @@ DESTINATION-DIR is the directory where the LSP server will be installed."
 (defun eglot-java--jdt-uri-handler (_operation &rest args)
   "Support Eclipse jdtls `jdt://' uri scheme."
   (let* ((uri (car args))
-         (cache-dir (expand-file-name ".eglot-java" (temporary-file-directory)))
+         (cache-dir (expand-file-name ".eglot-java" (project-root (project-current t))))
          (source-file
           (expand-file-name
            (eglot-java--make-path
